==> clickandpledge_connect-8.x-1.2002000101.tar.gz: clickandpledge_connect/src/Form/CnPAccountForm.php <==
<?php

namespace Drupal\clickandpledge_connect\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Database\Connection;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Uses to display all CONNECT forms.
 *
 * This class will display all account forms in a table grid view, where as
 * we can perform VIEW,EDIT,DELETE operations.
 */
class CnPAccountForm extends FormBase {

  /**
   * The Connection.
   *
   * @var mixed
   */
  protected $connection;

  /**
   * The Class Constructor.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The database connection.
   */
  public function __construct(Connection $connection) {
    $this->connection = $connection;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database')
    );
  }

  /**
   * {@inheritdoc}
   * */
  public function getFormId() {
    return 'cnpcaccount_settings_form';
  }

  /**
   * {@inheritdoc}
   * */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $displayForm = $this->displayAccountSettingsForm($form, $form_state);
    return $displayForm;
  }

  /**
   * Display all connect forms from the database.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param mixed $form_state
   *   The current state of the form.
   *
   * @return array
   *   Returns The form structure.
   */
  public function displayAccountSettingsForm(array $form, $form_state) {
    $form['base_url_cnpc'] = [
      '#type' => 'hidden',
      '#default_value' => base_path(),
      '#attributes' => ['id' => 'base_url_cnpc'],
    ];
    $form['cnpc_menu'] = [
      '#prefix' => '<div class="cnp_heading"><ul>
                                          <li><a href="cnp_form_help">' . $this->t("Click & Pledge") . '</a></li>
                                          <li><a class="cnpccurrent" href="cnp_form">' . $this->t("Form Groups") . '</a></li>
      <li><a href="cnppledgetvchannels">pledgeTV <sup class="cnpc-regsymbol">&reg;</sup></a></li>
                                          <li><a href="cnp_formssettings">' . $this->t("Settings") . '</a></li>
                                          </ul>',
      '#suffix' => '</div>',
    ];
    $form['cnpc_heading'] = [
      '#prefix' => '<div class="cnp_heading1">',
      '#suffix' => '</div>',
    ];
    $html = '<div class="cnpc-btn-center"><a href="add_form_group" class="cnpc_button_link_add">' . $this->t("Add New Form Group") . '</a></div>';
    $form['button_link_html'] = [
      '#type' => 'markup',
      '#markup' => $html,
    ];
    $form['table_group_start'] = [
      '#prefix' => '<div class="tablelist_group">',
    ];
    if (count($this->getRecords()) > 0) {
      $form['table_tag_start'] = [
        '#prefix' => '<div><table id="table_form_group" class="table_form_group">
                      <thead>
                          <tr>
                                                                      <th>' . $this->t('Group Name') . '</th>
                                                                      <th>' . $this->t('Account#') . '</th>
                                                                      <th>' . $this->t('Type') . '</th>
                                      <th>Short Code <span class="cnpc_question">&#63;</span><div class="cnpc_shortcode_tooltip">Please copy this code and place it in your required content pages, posts or any custom content types. This code will run the series of the forms which has been added to this particular Form Group inside your content page.</div></th>
                                                                      <th>' . $this->t('Start Date/Time') . '</th>
                                                                      <th>' . $this->t('End Date/Time') . '</th>
                                                                      <th>' . $this->t('Active Form(s)') . '</th>
                                                                      <th>' . $this->t('Last Modified') . '</th>
                                                                      <th>' . $this->t('Status') . '</th>
                                                                      <th>' . $this->t('Actions') . '</th>
                          </tr>
                      </thead>
                                                            <tbody>',
      ];
      $formGroups = $this->getRecords();
      $rg = 1;
      foreach ($formGroups as $fg) {
        if ($fg->cnpform_Form_EndDate == '0000-00-00 00:00:00') {
          $enddate = '';
        }
        else {
          $enddate = date('F d, Y h:i:s a', strtotime($fg->cnpform_Form_EndDate));
        }

        if ($this->checkFormsExpiry($fg->cnpform_Form_StartDate, $enddate) == "no") {
          $flink = "<a id='formstatus_" . $fg->cnpform_GID . "' class='formstatus' href='' data-fgid='" . $fg->cnpform_GID . "' data-fstatus='" . $fg->cnpform_status . "'>" . $fg->cnpform_status . "</a>";
        }
        else {
          $flink = '<a class="formstatus">Expired</a>';
        }
        $form['table_row_form_groups_' . $rg] = [
          '#prefix' => '<tr>
                                          <td>' . $fg->cnpform_groupname . '</td>
                                          <td>' . $fg->cnpform_AccountNumber . '</td>
                                          <td><span class="cnpform_type">' . $fg->cnpform_type . '</span></td>
                                          <td>' . $fg->cnpform_shortcode . '</td>
                                          <td>' . date('F d, Y h:i:s a', strtotime($fg->cnpform_Form_StartDate)) . '</td>
                                          <td>' . $enddate . '</td>
                                          <td>' . count($this->getNoofForms($fg->cnpform_GID)) . '</td>
                                          <td>' . date('F d, Y h:i:s a', strtotime($fg->cnpform_Date_Modified)) . '</td>
                                          <td>' . $flink . '</td>
                                          <td><a href="viewforms/' . $fg->cnpform_GID . '"><span class="view_icon"></span></a> | <a href="editforms/' . $fg->cnpform_GID . '"><span class="edit_icon"></span></a> | <a id="deleteFormInfo" class="deleteFormInfo" data-recid="' . $fg->cnpform_GID . '" href="#"><span class="bin_icon"></span></a> </td>',
          '#suffix' => '</tr>',
        ];
        $rg++;
      }
      $form['table_tag_end'] = [
        '#suffix' => '</tbody></table></div>',
      ];
    }
    else {
      $form['no_records'] = [
        '#prefix' => '<div><h3>' . $this->t('No Records Found.') . '</h3>',
        '#suffix' => '</div>',
      ];
    }
    $form['table_group_end'] = [
      '#suffix' => '</div>',
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   * */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Saving form data handling with ajax call.
  }

  /**
   * Get all the CONNECT form records.
   *
   * @return array
   *   Returns an array contains form details.
   */
  public function getRecords() {
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpc_forminfo';
    $sql = "SELECT cnpform_GID,cnpform_groupname,cnpform_cnpstngs_ID,cnpform_AccountNumber,"
      . "cnpform_guid,cnpform_type,cnpform_ptype,cnpform_text,cnpform_img,cnpform_shortcode,"
      . "cnpform_custommsg,cnpform_Form_StartDate,cnpform_Form_EndDate,cnpform_status,"
      . "cnpform_Date_Created,cnpform_Date_Modified FROM " . $table_name;
    $query = $this->connection->query($sql);
    return $query->fetchAll();
  }

  /**
   * Get total no.of forms to display the count in the table view.
   *
   * @param int $id
   *   The form group id.
   *
   * @return array
   *   Get the total no.of forms.
   */
  public function getNoofForms($id) {
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpc_formsdtl';
    $sql = "SELECT cnpform_id,cnpform_cnpform_ID,cnpform_CampaignName,cnpform_FormName,cnpform_GUID,"
      . "cnpform_FormStartDate,cnpform_FormEndDate,cnpform_urlparameters,cnpform_FormStatus,"
      . "cnpform_DateCreated,cnpform_DateModified FROM " . $table_name . " where cnpform_cnpform_ID=" . $id;
    $query = $this->connection->query($sql);
    return $query->fetchAll();
  }

  /**
   * Calculates the expiration date of forms,if expired,displays 'Expired'.
   *
   * @param mixed $startDT
   *   Start date.
   * @param mixed $endDT
   *   End date.
   *
   * @return string
   *   Returns a string if form expired 'yes' otherwise 'no'.
   */
  public function checkFormsExpiry($startDT, $endDT) {
    date_default_timezone_set(drupal_get_user_timezone());
    $currDT = date('Y-m-d h:i:s a');
    $currDT = strtotime($currDT);
    $startDT = strtotime($startDT);
    $endDT = strtotime($endDT);
    if ($startDT > $currDT) {
      return 'no';
    }
    if ($endDT) {
      if (($currDT >= $startDT) && ($currDT <= $endDT)) {
        return 'no';
      }
      else {
        return 'yes';
      }
    }
    else {
      return 'no';
    }
  }

}

==> clickandpledge_connect-8.x-1.2003000101.tar.gz: clickandpledge_connect/src/Form/CnPAccountForm.php <==
<?php

namespace Drupal\clickandpledge_connect\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Database\Connection;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Url;
use Drupal\Core\Access\CsrfTokenGenerator;

/**
 * Uses to display all CONNECT forms.
 *
 * This class will display all account forms in a table grid view, where as
 * we can perform VIEW,EDIT,DELETE operations.
 */
class CnPAccountForm extends FormBase {

  /**
   * The Connection.
   *
   * @var mixed
   */
  protected $connection;

  /**
   * The CSRF token generator.
   *
   * @var \Drupal\Core\Access\CsrfTokenGenerator
   */
  protected $csrfToken;

  /**
   * The class constructor.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The Database connection.
   * @param \Drupal\Core\Access\CsrfTokenGenerator $csrf_token
   *   The CSRF token generator.
   */
  public function __construct(Connection $connection, CsrfTokenGenerator $csrf_token) {
    $this->connection = $connection;
    $this->csrfToken = $csrf_token;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database'), $container->get('csrf_token')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'cnpcaccount_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $displayForm = $this->displayAccountSettingsForm($form, $form_state);
    return $displayForm;
  }

  /**
   * Display all connect forms from the database.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param mixed $form_state
   *   The current state of the form.
   *
   * @return array
   *   Returns The form structure.
   */
  public function displayAccountSettingsForm(array $form, $form_state) {
    $form['base_url_cnpc'] = [
      '#type' => 'hidden',
      '#default_value' => base_path(),
      '#attributes' => ['id' => 'base_url_cnpc'],
    ];
    $form['cnpc_menu'] = [
      '#prefix' => '<div class="cnp_heading"><ul>
                                          <li><a href="cnp_form_help">' . $this->t("Click & Pledge") . '</a></li>
                                          <li><a class="cnpccurrent" href="cnp_form">' . $this->t("Form Groups") . '</a></li>
      <li><a href="cnppledgetvchannels">pledgeTV <sup class="cnpc-regsymbol">&reg;</sup></a></li>
                                          <li><a href="cnp_formssettings">' . $this->t("Settings") . '</a></li>
                                          </ul>',
      '#suffix' => '</div>',
    ];
    $form['cnpc_heading'] = [
      '#prefix' => '<div class="cnp_heading1">',
      '#suffix' => '</div>',
    ];
    $html = '<div class="cnpc-btn-center"><a href="add_form_group" class="cnpc_button_link_add">' . $this->t("Add New Form Group") . '</a></div>';
    $form['button_link_html'] = [
      '#type' => 'markup',
      '#markup' => $html,
    ];
    $form['table_group_start'] = [
      '#prefix' => '<div class="tablelist_group">',
    ];
    if (count($this->getRecords()) > 0) {
      $form['table_tag_start'] = [
        '#prefix' => '<div><table id="table_form_group" class="table_form_group">
                      <thead>
                          <tr>
                                                                      <th>' . $this->t('Group Name') . '</th>
                                                                      <th>' . $this->t('Account#') . '</th>
                                                                      <th>' . $this->t('Type') . '</th>
                                      <th>Short Code <span class="cnpc_question">&#63;</span><div class="cnpc_shortcode_tooltip">Please copy this code and place it in your required content pages, posts or any custom content types. This code will run the series of the forms which has been added to this particular Form Group inside your content page.</div></th>
                                                                      <th>' . $this->t('Start Date/Time') . '</th>
                                                                      <th>' . $this->t('End Date/Time') . '</th>
                                                                      <th>' . $this->t('Active Form(s)') . '</th>
                                                                      <th>' . $this->t('Last Modified') . '</th>
                                                                      <th>' . $this->t('Status') . '</th>
                                                                      <th>' . $this->t('Actions') . '</th>
                          </tr>
                      </thead>
                                                            <tbody>',
      ];
      $formGroups = $this->getRecords();
      $rg = 1;
      foreach ($formGroups as $fg) {
        $urlParams = ['variable' => $fg->cnpform_GID];
        $statusParams = ['variableone' => $fg->cnpform_status, 'variabletwo' => $fg->cnpform_GID];
        if ($fg->cnpform_Form_EndDate == '0000-00-00 00:00:00') {
          $enddate = '';
        }
        else {
          $enddate = date('F d, Y h:i:s a', strtotime($fg->cnpform_Form_EndDate));
        }

        if ($this->checkFormsExpiry($fg->cnpform_Form_StartDate, $enddate) == "no") {
          $flink = "<a id='formstatus_" . $fg->cnpform_GID . "' class='formstatus' href='" . $this->cnpGenerateTokenUrl('cnpconnect.cnpc_update_form_status', $statusParams) . "' data-fgid='" . $fg->cnpform_GID . "' data-fstatus='" . $fg->cnpform_status . "'>" . $fg->cnpform_status . "</a>";
        }
        else {
          $flink = '<a class="formstatus">Expired</a>';
        }
        $form['table_row_form_groups_' . $rg] = [
          '#prefix' => '<tr>
                                          <td>' . $fg->cnpform_groupname . '</td>
                                          <td>' . $fg->cnpform_AccountNumber . '</td>
                                          <td><span class="cnpform_type">' . $fg->cnpform_type . '</span></td>
                                          <td>' . $fg->cnpform_shortcode . '</td>
                                          <td>' . date('F d, Y h:i:s a', strtotime($fg->cnpform_Form_StartDate)) . '</td>
                                          <td>' . $enddate . '</td>
                                          <td>' . count($this->getNoofForms($fg->cnpform_GID)) . '</td>
                                          <td>' . date('F d, Y h:i:s a', strtotime($fg->cnpform_Date_Modified)) . '</td>
                                          <td>' . $flink . '</td>
                                          <td><a href="' . $this->cnpGenerateTokenUrl('cnpconnect.viewforms', $urlParams) . '"><span class="view_icon"></span></a> | <a href="' . $this->cnpGenerateTokenUrl('cnpconnect.editforms', $urlParams) . '"><span class="edit_icon"></span></a> | <a id="deleteFormInfo" class="deleteFormInfo" data-recid="' . $fg->cnpform_GID . '" href="' . $this->cnpGenerateTokenUrl('cnpconnect.cnpc_deleteformgroups', $urlParams) . '"><span class="bin_icon"></span></a> </td>',
          '#suffix' => '</tr>',
        ];
        $rg++;
      }
      $form['table_tag_end'] = [
        '#suffix' => '</tbody></table></div>',
      ];
    }
    else {
      $form['no_records'] = [
        '#prefix' => '<div><h3>' . $this->t('No Records Found.') . '</h3>',
        '#suffix' => '</div>',
      ];
    }
    $form['table_group_end'] = [
      '#suffix' => '</div>',
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   * */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Saving form data handling with ajax call.
  }

  /**
   * Get all the CONNECT form records.
   *
   * @return array
   *   Returns an array contains form details.
   */
  public function getRecords() {
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpc_forminfo';
    $sql = "SELECT cnpform_GID,cnpform_groupname,cnpform_cnpstngs_ID,cnpform_AccountNumber,"
      . "cnpform_guid,cnpform_type,cnpform_ptype,cnpform_text,cnpform_img,cnpform_shortcode,"
      . "cnpform_custommsg,cnpform_Form_StartDate,cnpform_Form_EndDate,cnpform_status,"
      . "cnpform_Date_Created,cnpform_Date_Modified FROM " . $table_name;
    $query = $this->connection->query($sql);
    return $query->fetchAll();
  }

  /**
   * Get total no.of forms to display the count in the table view.
   *
   * @param int $id
   *   The form group id.
   *
   * @return array
   *   Get the total no.of forms.
   */
  public function getNoofForms($id) {
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpc_formsdtl';
    $sql = "SELECT cnpform_id,cnpform_cnpform_ID,cnpform_CampaignName,cnpform_FormName,cnpform_GUID,"
      . "cnpform_FormStartDate,cnpform_FormEndDate,cnpform_urlparameters,cnpform_FormStatus,"
      . "cnpform_DateCreated,cnpform_DateModified FROM " . $table_name . " where cnpform_cnpform_ID=" . $id;
    $query = $this->connection->query($sql);
    return $query->fetchAll();
  }

  /**
   * Calculates the expiration date of forms,if expired,displays 'Expired'.
   *
   * @param mixed $startDT
   *   Start date.
   * @param mixed $endDT
   *   End date.
   *
   * @return string
   *   Returns a string if form expired 'yes' otherwise 'no'.
   */
  public function checkFormsExpiry($startDT, $endDT) {
    date_default_timezone_set(drupal_get_user_timezone());
    $currDT = date('Y-m-d h:i:s a');
    $currDT = strtotime($currDT);
    $startDT = strtotime($startDT);
    $endDT = strtotime($endDT);
    if ($startDT > $currDT) {
      return 'no';
    }
    if ($endDT) {
      if (($currDT >= $startDT) && ($currDT <= $endDT)) {
        return 'no';
      }
      else {
        return 'yes';
      }
    }
    else {
      return 'no';
    }
  }

  /**
   * Creates an URL string with a token by appending in query string.
   *
   * @param mixed $routeName
   *   Name of the route to generate the URL.
   * @param mixed $urlParams
   *   Contains URL parameters as an array.
   *
   * @return mixed
   *   Return an absolute URL with token
   */
  public function cnpGenerateTokenUrl($routeName, $urlParams) {
    $url = Url::fromRoute($routeName, $urlParams);
    $token = $this->csrfToken->get($url->getInternalPath());
    $url->setOptions(['absolute' => TRUE, 'query' => ['token' => $token]]);
    return $url->toString();
  }

}
